summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorTreehugger Robot <treehugger-gerrit@google.com>2020-07-28 19:49:40 +0000
committerAutomerger Merge Worker <android-build-automerger-merge-worker@system.gserviceaccount.com>2020-07-28 19:49:40 +0000
commit7adada7f4403f8b2beed474116a35479485f2585 (patch)
tree0aba727199b7138ecb60a5a9395c3d3fb1f7708d /src
parent089f3343f0fd2be542a4baaefe49b872116a0e66 (diff)
parent7e82370fedc35d0229365c519b8a5e88d3c5555d (diff)
downloadCamera2-7adada7f4403f8b2beed474116a35479485f2585.tar.gz
Merge "AOSP/Camera2 - Update language to comply with Android's inclusive language guidance" am: d30e72b9d7 am: 7e82370fed
Original change: https://android-review.googlesource.com/c/platform/packages/apps/Camera2/+/1373758 Change-Id: Icdc77d151e69da71ffae767403abad5fbdb29371
Diffstat (limited to 'src')
-rw-r--r--src/com/android/camera/app/NoOpLocationProvider.java2
-rw-r--r--src/com/android/camera/data/FilmstripItemUtils.java4
-rw-r--r--src/com/android/camera/data/PhotoItem.java4
-rw-r--r--src/com/android/camera/processing/imagebackend/TaskConvertImageToRGBPreview.java12
-rw-r--r--src/com/android/camera/processing/imagebackend/TaskJpegEncode.java4
5 files changed, 13 insertions, 13 deletions
diff --git a/src/com/android/camera/app/NoOpLocationProvider.java b/src/com/android/camera/app/NoOpLocationProvider.java
index 1cdbda3ef..f66a19bac 100644
--- a/src/com/android/camera/app/NoOpLocationProvider.java
+++ b/src/com/android/camera/app/NoOpLocationProvider.java
@@ -20,7 +20,7 @@ import android.content.Context;
import android.location.Location;
/**
- * Dummy Location provider to be used when location information shouldn't be provided to the client.
+ * No-op Location provider to be used when location information shouldn't be provided to the client.
*/
public class NoOpLocationProvider implements LocationProvider {
diff --git a/src/com/android/camera/data/FilmstripItemUtils.java b/src/com/android/camera/data/FilmstripItemUtils.java
index ac0a8ea4b..654bf49e2 100644
--- a/src/com/android/camera/data/FilmstripItemUtils.java
+++ b/src/com/android/camera/data/FilmstripItemUtils.java
@@ -95,9 +95,9 @@ public class FilmstripItemUtils {
byte[] decodeBuffer = new byte[32 * 1024];
if (orientation % 180 != 0) {
- int dummy = imageHeight;
+ int temp = imageHeight;
imageHeight = imageWidth;
- imageWidth = dummy;
+ imageWidth = temp;
}
// Generate Bitmap of maximum size that fits into widthBound x heightBound.
diff --git a/src/com/android/camera/data/PhotoItem.java b/src/com/android/camera/data/PhotoItem.java
index 8215f7363..0dcacb1c1 100644
--- a/src/com/android/camera/data/PhotoItem.java
+++ b/src/com/android/camera/data/PhotoItem.java
@@ -246,9 +246,9 @@ public class PhotoItem extends FilmstripItemBase<FilmstripItemData> {
// If the orientation is not vertical
if (orientation % 180 != 0) {
- int dummy = dim.x;
+ int temp = dim.x;
dim.x = dim.y;
- dim.y = dummy;
+ dim.y = temp;
}
bitmap = FilmstripItemUtils
diff --git a/src/com/android/camera/processing/imagebackend/TaskConvertImageToRGBPreview.java b/src/com/android/camera/processing/imagebackend/TaskConvertImageToRGBPreview.java
index fbbbaa576..a4b0886de 100644
--- a/src/com/android/camera/processing/imagebackend/TaskConvertImageToRGBPreview.java
+++ b/src/com/android/camera/processing/imagebackend/TaskConvertImageToRGBPreview.java
@@ -111,7 +111,7 @@ public class TaskConvertImageToRGBPreview extends TaskImageContainer {
/**
* Way to calculate the resultant image sizes of inscribed circles:
* colorInscribedDataCircleFromYuvImage,
- * dummyColorInscribedDataCircleFromYuvImage, colorDataCircleFromYuvImage
+ * stubColorInscribedDataCircleFromYuvImage, colorDataCircleFromYuvImage
*
* @param height height of the input image
* @param width width of the input image
@@ -202,7 +202,7 @@ public class TaskConvertImageToRGBPreview extends TaskImageContainer {
* <p>
* <b>Known Image Artifacts</b> Since this class produces bitmaps that are
* transient on the screen, the implementation is geared toward efficiency
- * rather than image quality. The image created is a straight, dumb integer
+ * rather than image quality. The image created is a straight, arbitrary integer
* subsample of the YUV space with an acceptable color conversion, but w/o any
* sort of re-sampling. So, expect the usual aliasing noise. Furthermore, when a
* subsample factor of n is chosen, the resultant UV pixels will have the same
@@ -518,7 +518,7 @@ public class TaskConvertImageToRGBPreview extends TaskImageContainer {
* <p>
* <b>Known Image Artifacts</b> Since this class produces bitmaps that are
* transient on the screen, the implementation is geared toward efficiency
- * rather than image quality. The image created is a straight, dumb integer
+ * rather than image quality. The image created is a straight, arbitrary integer
* subsample of the YUV space with an acceptable color conversion, but w/o any
* sort of re-sampling. So, expect the usual aliasing noise. Furthermore, when a
* subsample factor of n is chosen, the resultant UV pixels will have the same
@@ -779,8 +779,8 @@ public class TaskConvertImageToRGBPreview extends TaskImageContainer {
* @param subsample width/height subsample factor
* @return inscribed image as ARGB_8888
*/
- protected int[] dummyColorInscribedDataCircleFromYuvImage(ImageProxy img, int subsample) {
- logWrapper("RUNNING DUMMY dummyColorInscribedDataCircleFromYuvImage");
+ protected int[] stubColorInscribedDataCircleFromYuvImage(ImageProxy img, int subsample) {
+ logWrapper("RUNNING STUB stubColorInscribedDataCircleFromYuvImage");
int w = img.getWidth() / subsample;
int h = img.getHeight() / subsample;
int r = inscribedCircleRadius(w, h);
@@ -847,7 +847,7 @@ public class TaskConvertImageToRGBPreview extends TaskImageContainer {
protected int[] runSelectedConversion(ImageProxy img, Rect crop, int subsample) {
switch (mThumbnailShape) {
case DEBUG_SQUARE_ASPECT_CIRCULAR_INSET:
- return dummyColorInscribedDataCircleFromYuvImage(img, subsample);
+ return stubColorInscribedDataCircleFromYuvImage(img, subsample);
case SQUARE_ASPECT_CIRCULAR_INSET:
return colorInscribedDataCircleFromYuvImage(img, crop, subsample);
case SQUARE_ASPECT_NO_INSET:
diff --git a/src/com/android/camera/processing/imagebackend/TaskJpegEncode.java b/src/com/android/camera/processing/imagebackend/TaskJpegEncode.java
index c818401ac..b1f1fbf19 100644
--- a/src/com/android/camera/processing/imagebackend/TaskJpegEncode.java
+++ b/src/com/android/camera/processing/imagebackend/TaskJpegEncode.java
@@ -124,13 +124,13 @@ public abstract class TaskJpegEncode extends TaskImageContainer {
}
/**
* Creates a dummy shaded image for testing in packed NV21 format.
*
* @param dataCopy Buffer to contained shaded test image
* @param w Width of image
* @param h Height of Image
*/
- public void dummyConvertYUV420ImageToPackedNV21(byte[] dataCopy,
+ public void stubConvertYUV420ImageToPackedNV21(byte[] dataCopy,
final int w, final int h) {
final int y_size = w * h;
final int data_offset = w * h;
@@ -124,13 +124,13 @@ public abstract class TaskJpegEncode extends TaskImageContainer {
}
/**
- * Creates a dummy shaded image for testing in packed NV21 format.
+ * Creates a stub shaded image for testing in packed NV21 format.
*
* @param dataCopy Buffer to contained shaded test image